extensions = ['sphinx.ext.autodoc', 'sphinx.ext.doctest', 'sphinx.ext.todo']
project = 'Gaphas'
version = '0.5'
release = version
source_suffix = '.txt'
master_doc = 'contents'
#html_theme = 'traditional'
unused_docs = 'constraints.txt index.txt comparison.txt'
